@@ -15,12 +15,9 @@ function(formula,nest.f2=c("fixed","random"),data=NULL,nperm=999) {
   if (length(variables)==2) {
     tab <- perm.anova.1way(resp,fact1,variables,nperm)$tab
   } else if (length(variables)==3) {
-    fact2 <- NULL
-    if (length(variables)>2) {
-	fact2 <- if (is.null(data)) {get(variables[3],pos=environment(formula))}
-	  else {get(variables[3],pos=get(deparse(substitute(data))))}
-    }
-    if (length(fact1)!=length(fact2)) {stop(paste("'",variables[2],"' and '",variables[3],"' lengths differ",sep=""))}
+    fact2 <- if (is.null(data)) {get(variables[3],pos=environment(formula))}
+	else {get(variables[3],pos=get(deparse(substitute(data))))}
+    if (length(resp)!=length(fact2)) {stop(paste("'",variables[1],"' and '",variables[3],"' lengths differ",sep=""))}
     if (!is.factor(fact2)) {fact2 <- factor(fact2)}
     if (all.names(formula)[3]=="+") {
 	tab <- perm.anova.2wayA(resp,fact1,fact2,variables,nperm)$tab
@@ -32,6 +29,24 @@ function(formula,nest.f2=c("fixed","random"),data=NULL,nperm=999) {
 	data.name <- paste(data.name,"\nBlock: ",variables[3],sep="")
 	tab <- perm.anova.2wayD(resp,fact1,fact2,variables,nperm)$tab
     }
+  } else if (length(variables)==4) {
+    if (all.names(formula)[3]!="|") {stop("incorrect 'formula'")}
+    fact2 <- if (is.null(data)) {get(variables[3],pos=environment(formula))}
+	else {get(variables[3],pos=get(deparse(substitute(data))))}
+    fact3 <- if (is.null(data)) {get(variables[4],pos=environment(formula))}
+	else {get(variables[4],pos=get(deparse(substitute(data))))}
+    if (length(resp)!=length(fact2)) {stop(paste("'",variables[1],"' and '",variables[3],"' lengths differ",sep=""))}
+    if (length(resp)!=length(fact3)) {stop(paste("'",variables[1],"' and '",variables[4],"' lengths differ",sep=""))}
+    if (!is.factor(fact2)) {fact2 <- factor(fact2)}
+    if (!is.factor(fact3)) {fact2 <- factor(fact3)}
+    data.name <- paste(data.name,"\nBlock: ",variables[4],sep="")
+    if (all.names(formula)[4]=="+") {
+	tab <- perm.anova.3wayA(resp,fact1,fact2,fact3,variables,nperm)$tab
+    } else if (all.names(formula)[4]=="*") {
+	tab <- perm.anova.3wayB(resp,fact1,fact2,fact3,variables,nperm)$tab
+    } else {
+	stop("only additive and multiplicative models are permitted")
+    }
   }
   tab[1:(nrow(tab)-1),ncol(tab)] <- psignif(tab[1:(nrow(tab)-1),"Pr(>F)"])
   result <- list(permutations=nperm,data.name=data.name,table=tab)
