@@ -1,5 +1,5 @@
 spearman.ci <-
-function(var1,var2,rep=1000,conf.level=0.95){
+function(var1,var2,nrep=1000,conf.level=0.95){
   if (length(var1)!=length(var2)) {stop(paste("'",deparse(substitute(var1)),"' and '",
     deparse(substitute(var2)),"' lengths differ",sep=""))}
   nul <- as.numeric(row.names(table(c(which(is.na(var1)),which(is.na(var2))))))
@@ -8,18 +8,10 @@ function(var1,var2,rep=1000,conf.level=0.95){
   cor.fun <- function(data,ind) {
     as.numeric(suppressWarnings(cor.test(data[ind,1],data[ind,2],method="spearman")$estimate))
   }
-  simul <- boot(data.frame(var1.2,var2.2),cor.fun,R=rep)
-  tri <- sort(simul$t)
-  int <- (1-conf.level)/2
-  if(rep*int<1) {
-    int.inf <- ceiling(rep*int)
-  } else {
-    int.inf <- floor(rep*int)
-  }
-  int.sup <- ceiling(rep*(1-int))
-  result <- list(conf.level=conf.level,rep=rep,
-    coeff=as.numeric(suppressWarnings(cor.test(var1,var2,method="spearman")$estimate)),
-    interval=c("Inf"=tri[int.inf],"Sup"=tri[int.sup]))
+  simul <- boot(data.frame(var1.2,var2.2),cor.fun,R=nrep)
+  interval <- ci(simul$t,conf.level=conf.level)
+  result <- list(conf.level=conf.level,rep=nrep,
+    coeff=as.numeric(suppressWarnings(cor.test(var1,var2,method="spearman")$estimate)),interval=interval)
   class(result) <- c("spearman.ci","list")
   return(result)
 }
